@@ -6,5 +6,5 @@ from .distributed import (
     PLUGIN_DIR, NSFW_TAGS,
     T_UserID, T_AuthorizedUserID, T_GroupID, T_AuthorizedGroupID,
     get_mac_address, convert_audio2wav,
-    fetch_image_in_message, inject_image_to_state
+    fetch_image_in_message, inject_image_to_state, preprocess_painting_parameters
 )
